@@ -57,7 +57,7 @@ use Time::Local;
 use Scalar::Util qw/reftype/;
 use List::Util qw/pairs any/;
 
-use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, NamingConventions::Capitalization)
+use constant { ## no critic (ValuesAndExpressions::ProhibitConstantPragma, NamingConventions::Capitalization)
   AWS_METADATA_BASE_URL            => q{http://169.254.169.254/},
   AWS_CONTAINER_CREDENTIALS_URL    => q{http://169.254.170.2/},
   AWS_IAM_SECURITY_CREDENTIALS_URL =>
@@ -67,7 +67,7 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Na
   COMMA                   => q{,},
   DEFAULT_CIPHER          => q{Cipher::AES},
   DEFAULT_SEARCH_ORDER    => q{env,container,role,file},
-  DEFAULT_TIMEOUT         => 3,
+  DEFAULT_TIMEOUT         => 2,
   DEFAULT_WINDOW_INTERVAL => 5,
   EMPTY                   => q{},
   SECONDS_IN_MINUTE       => 60,
@@ -86,13 +86,13 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Na
   LOG_FORMAT              => qq{ %s [%s] %s\n },
 };
 
-our $VERSION = '1.1.8';
+our $VERSION = '1.1.9';
 
 our @EXPORT_OK = qw{ create_passkey };
 
 # we only log at debug level, create a default logger
 {
-  no strict 'refs';    ## no critic (TestingAndDebugging::ProhibitNoStrict)
+  no strict 'refs'; ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
   *{'Amazon::Credentials::Logger::debug'} = sub {
     my ( $self, @message ) = @_;
@@ -127,7 +127,7 @@ sub new {
     $self->get_logger->debug( "!! CAUTION !!\n"
         . "!! You are executing in 'insecure' mode !!\n"
         . "!! Credentials may be exposed in debug messages !!\n" );
-  }
+  } ## end if ( $self->get_insecure)
 
   if ( !$options->{'aws_secret_access_key'}
     || !$options->{'aws_access_key_id'} ) {
@@ -135,21 +135,21 @@ sub new {
 
     if ( $self->get__session_token ) {
       $self->set_session_token_required(TRUE);
-    }
+    } ## end if ( $self->get__session_token)
 
     if ( !$self->get_cache ) {
       $self->reset_credentials;
-    }
+    } ## end if ( !$self->get_cache)
   } ## end if ( !$options->{'aws_secret_access_key'...})
   else {
     $self->set_credentials($options);
-  }
+  } ## end else [ if ( !$options->{'aws_secret_access_key'...})]
 
   if ( !$self->get_region ) {
     $self->set_region( $ENV{'AWS_REGION'}
         || $ENV{'AWS_DEFAULT_REGION'}
         || $self->get_default_region );
-  }
+  } ## end if ( !$self->get_region)
 
   return $self;
 } ## end sub new
@@ -177,12 +177,12 @@ sub reset_credentials {
     $self->set__access_key_id(undef);
     $self->set__secret_access_key(undef);
     $self->set__session_token(undef);
-  }
+  } ## end if ( !$renew )
   else {
     if ( $self->get_cache ) {
       $self->set_credentials;
-    }
-  }
+    } ## end if ( $self->get_cache )
+  } ## end else [ if ( !$renew ) ]
 
   return $self;
 } ## end sub reset_credentials
@@ -191,8 +191,10 @@ sub reset_credentials {
 sub get_default_region {
 ########################################################################
   my ($self) = @_;
-  my $region;
 
+  my $region = $self->get_region_from_config;
+
+  # only do this if we are sure we are on an EC2
   if ( $self->get_source && $self->get_source eq 'IAM' ) {
     # try to get credentials from instance role, but we may not be
     # executing on an EC2 or container
@@ -200,10 +202,10 @@ sub get_default_region {
 
     if ( $self->get_container ) {
       $url = "$ENV{ECS_CONTAINER_METADATA_URI_V4}/task";
-    }
+    } ## end if ( $self->get_container)
     else {
       $url = _create_metadata_url(AWS_AVAILABILITY_ZONE_URL);
-    }
+    } ## end else [ if ( $self->get_container)]
 
     my $ua = ref $self ? $self->get_user_agent : LWP::UserAgent->new();
 
@@ -212,7 +214,7 @@ sub get_default_region {
     # add imdsv2 token to metadata request
     if ( !$self->get_container && $self->get_imdsv2_token ) {
       @headers = ( IMDSv2_HEADER => $self->get_imdsv2_token );
-    }
+    } ## end if ( !$self->get_container...)
 
     my $req = HTTP::Request->new( GET => $url, \@headers );
 
@@ -243,7 +245,7 @@ sub set_credentials {
   $creds = eval {
     if ( !$creds ) {
       $creds = eval { return $self->find_credentials };
-    }
+    } ## end if ( !$creds )
 
     $self->set_error( $creds->{'error'} || $EVAL_ERROR );
 
@@ -263,7 +265,7 @@ sub set_credentials {
 
   if ( $EVAL_ERROR && !$self->get_error ) {
     $self->set_error($EVAL_ERROR);
-  }
+  } ## end if ( $EVAL_ERROR && !$self...)
 
   undef $EVAL_ERROR;
 
@@ -282,7 +284,7 @@ sub set_credentials {
 sub get_ec2_credentials {
 ########################################################################
   goto &find_credentials;
-}
+} ## end sub get_ec2_credentials
 
 ########################################################################
 sub find_credentials {
@@ -293,23 +295,23 @@ sub find_credentials {
 
   if ( $options->{'profile'} ) {
     $self->set_profile( $options->{'profile'} );
-  }
+  } ## end if ( $options->{'profile'...})
 
   if ( $options->{'order'} ) {
     $self->set_order( $options->{'order'} );
-  }
+  } ## end if ( $options->{'order'...})
 
   my @search_order;
 
   if ( $self->get_profile ) {
     @search_order = ('file');
-  }
+  } ## end if ( $self->get_profile)
   elsif ( ref $self->get_order && reftype( $self->get_order ) eq 'ARRAY' ) {
     @search_order = @{ $self->get_order };
-  }
+  } ## end elsif ( ref $self->get_order...)
   elsif ( !ref $self->get_order ) {
     @search_order = split /\s*,\s*/xsm, $self->get_order;
-  }
+  } ## end elsif ( !ref $self->get_order)
 
   $self->get_logger->debug( 'search order ' . join COMMA, @search_order );
 
@@ -336,7 +338,7 @@ sub find_credentials {
 
     if ( $creds_getters{$location} ) {
       $creds = $creds_getters{$location}->();
-    }
+    } ## end if ( $creds_getters{$location...})
 
     last if $creds->{'source'};
   } ## end foreach my $location (@search_order)
@@ -345,10 +347,10 @@ sub find_credentials {
 
     if ( $k !~ /^aws|token/xsm ) {
       $self->set( $k,, $creds->{$k} );
-    }
+    } ## end if ( $k !~ /^aws|token/xsm)
     elsif ( $self->can("set_$k") ) {
       $self->can("set_$k")->( $self, $creds->{$k} );
-    }
+    } ## end elsif ( $self->can("set_$k"...))
   } ## end foreach my $k ( keys %{$creds...})
 
   $self->get_logger->debug( $self->safe_dumper($creds) );
@@ -375,7 +377,7 @@ sub get_creds_from_env {
 
   if ( $ENV{'AWS_ACCESS_KEY_ID'} && $ENV{'AWS_SECRET_ACCESS_KEY'} ) {
     @{$creds}{@cred_keys} = ( 'ENV', @ENV{@env_keys} );
-  }
+  } ## end if ( $ENV{'AWS_ACCESS_KEY_ID'...})
 
   return $creds;
 } ## end sub get_creds_from_env
@@ -400,7 +402,7 @@ sub get_creds_from_process {
 
   if ( $EVAL_ERROR || !$credentials ) {
     croak "could not get credentials from process\n$EVAL_ERROR\n";
-  }
+  } ## end if ( $EVAL_ERROR || !$credentials)
 
   $self->get_logger->debug( $self->safe_dumper($credentials) );
 
@@ -418,7 +420,7 @@ sub get_creds_from_process {
     if ( exists $credentials->{$v} ) {
       $credentials->{$k} = $credentials->{$v};
       delete $credentials->{$v};
-    }
+    } ## end if ( exists $credentials...)
   } ## end foreach my $pair ( pairs @credential_keys)
 
   $credentials->{'source'} = 'process';
@@ -426,6 +428,40 @@ sub get_creds_from_process {
   return $credentials;
 } ## end sub get_creds_from_process
 
+########################################################################
+sub create_config_path {
+########################################################################
+  my ($config) = @_;
+
+  my $fullpath = home . SLASH . $config;
+
+  return -e $fullpath ? $fullpath : EMPTY;
+} ## end sub create_config_path
+
+########################################################################
+sub get_region_from_config {
+########################################################################
+  my ($self) = @_;
+
+  my $config = create_config_path('.aws/config');
+
+  return if !$config;
+
+  $self->get_logger->debug("config: $config");
+
+  my $ini = Config::Tiny->read($config);
+
+  my $region;
+
+  if ( $ini->{'default'} ) {
+    $region = $ini->{'default'}->{'region'};
+  } ## end if ( $ini->{'default'})
+
+  $self->get_logger->debug( "default region: " . $region // "undef" );
+
+  return $region;
+} ## end sub get_region_from_config
+
 ########################################################################
 sub get_creds_from_ini_file {
 ########################################################################
@@ -434,7 +470,6 @@ sub get_creds_from_ini_file {
   $profile = $profile || $self->get_profile || 'default';
 
   my $creds = {};
-  my $cwd   = $CWD;
   my $region;
 
   foreach my $config (qw{ .aws/config .aws/credentials }) {
@@ -442,18 +477,16 @@ sub get_creds_from_ini_file {
 
     my $profile_name = $profile;
 
-    $CWD = home;
+    my $fullpath = create_config_path($config);
 
-    my $fullpath = $CWD . SLASH . $config;
-
-    if ( !-e $config ) {
-      $self->get_logger->debug( 'skipping ' . $fullpath . '...not found' );
+    if ( !$fullpath ) {
+      $self->get_logger->debug( 'skipping ' . $config . '...not found' );
       next;
-    }
+    } ## end if ( !$fullpath )
 
-    $self->get_logger->debug( 'reading ' . $fullpath );
+    $self->get_logger->debug( 'reading ' . $config );
 
-    my $ini = Config::Tiny->read($config);
+    my $ini = Config::Tiny->read($fullpath);
 
     $self->get_logger->debug( $self->safe_dumper($ini) );
 
@@ -461,18 +494,19 @@ sub get_creds_from_ini_file {
       next if !$ini->{'default'}->{'profile'};
 
       $profile_name = $ini->{'default'}->{'profile'};
-    }
-
-    $region = $ini->{'region'};
+    } ## end if ( $profile eq 'default')
+    elsif ( $ini->{'default'} ) {
+      $region = $ini->{'default'}->{'region'};
+    } ## end elsif ( $ini->{'default'})
 
     my $section;
 
     if ( $ini->{$profile_name} ) {
       $section = $ini->{$profile_name};
-    }
+    } ## end if ( $ini->{$profile_name...})
     elsif ( $ini->{"profile $profile_name"} ) {
       $section = $ini->{"profile $profile_name"};
-    }
+    } ## end elsif ( $ini->{"profile $profile_name"...})
 
     my $process
       = $ini->{'credential_process'} || $section->{'credential_process'};
@@ -480,7 +514,7 @@ sub get_creds_from_ini_file {
     if ($process) {
       $creds  = $self->get_creds_from_process($process);
       $region = $section->{'region'} ? $section->{'region'} : $region;
-    }
+    } ## end if ($process)
     elsif ($section) {
       my @cred_keys = qw{
         aws_access_key_id
@@ -492,15 +526,13 @@ sub get_creds_from_ini_file {
       foreach my $k (@cred_keys) {
         if ( defined $section->{$k} ) {
           $creds->{$k} = $section->{$k};
-        }
-      }
+        } ## end if ( defined $section->...)
+      } ## end foreach my $k (@cred_keys)
 
       $creds->{'source'} = $creds->{'aws_access_key_id'} ? $config : undef;
     } ## end elsif ($section)
   } ## end foreach my $config (qw{ .aws/config .aws/credentials })
 
-  $CWD = $cwd;
-
   $self->set_region( $creds->{'region'} || $region );
 
   return $creds;
@@ -532,10 +564,10 @@ sub get_creds_from_role {
 
     if ( $rsp->is_success ) {
       $self->set_imdsv2_token( $rsp->content );
-    }
+    } ## end if ( $rsp->is_success )
     else {
       croak "could not retrieve IMDSv2 token\n";
-    }
+    } ## end else [ if ( $rsp->is_success )]
   } ## end if ( $self->get_imdsv2)
 
   $creds = eval {
@@ -545,13 +577,13 @@ sub get_creds_from_role {
 
       if ($role) {
         $url .= $role;
-      }
+      } ## end if ($role)
 
       my @headers;
 
       if ( $self->get_imdsv2 && $self->get_imdsv2_token ) {
         @headers = ( IMDSv2_HEADER, $self->get_imdsv2_token );
-      }
+      } ## end if ( $self->get_imdsv2...)
 
       my $req = HTTP::Request->new( GET => $url, \@headers );
 
@@ -589,7 +621,7 @@ sub get_creds_from_role {
 
   if ($EVAL_ERROR) {
     $creds->{'error'} = $EVAL_ERROR;
-  }
+  } ## end if ($EVAL_ERROR)
 
   return $creds;
 } ## end sub get_creds_from_role
@@ -636,7 +668,7 @@ sub get_creds_from_container {
       } ## end if ( $rsp->is_success )
       else {
         $self->get_logger->debug( 'return code: ' . $rsp->status_line );
-      }
+      } ## end else [ if ( $rsp->is_success )]
 
       return $creds;
     };
@@ -648,7 +680,7 @@ sub get_creds_from_container {
   else {
     $self->get_logger->debug(
       "not running in a container: no URI in environment\n");
-  }
+  } ## end else [ if ($uri) ]
 
   return $creds;
 } ## end sub get_creds_from_container
@@ -668,7 +700,7 @@ sub safe_dumper {
 
   if ( $self->get_insecure && $self->get_insecure =~ /^2$/xsm ) {
     $safe_rsp = Dumper [$obj];
-  }
+  } ## end if ( $self->get_insecure...)
   elsif ( $self->get_insecure ) {
     $safe_rsp = Dumper [$obj];
 
@@ -682,7 +714,7 @@ sub safe_dumper {
   } ## end elsif ( $self->get_insecure)
   else {
     $safe_rsp = '** configuration contents blocked by insecure setting **';
-  }
+  } ## end else [ if ( $self->get_insecure...)]
 
   return $safe_rsp;
 } ## end sub safe_dumper
@@ -696,7 +728,7 @@ sub dump_response {
 
   if ( $self->get_insecure && $self->get_insecure =~ /^2$/xsm ) {
     $safe_rsp = $rsp;
-  }
+  } ## end if ( $self->get_insecure...)
   elsif ( $self->get_insecure ) {
     $safe_rsp = {};
 
@@ -709,12 +741,12 @@ sub dump_response {
       } ## end if ( $k =~ /content/xsm)
       else {
         $safe_rsp->{$k} = $rsp->{$k};
-      }
+      } ## end else [ if ( $k =~ /content/xsm)]
     } ## end foreach my $k ( keys %{$rsp...})
   } ## end elsif ( $self->get_insecure)
   else {
     $safe_rsp = '** HTTP RESPONSE blocked by insecure setting **';
-  }
+  } ## end else [ if ( $self->get_insecure...)]
 
   return Dumper [$safe_rsp];
 } ## end sub dump_response
@@ -769,7 +801,7 @@ sub is_token_expired {
 sub refresh_credentials {
 ########################################################################
   goto &refresh_token;
-}
+} ## end sub refresh_credentials
 
 ########################################################################
 sub refresh_token {
@@ -779,10 +811,10 @@ sub refresh_token {
 
   if ( $self->get_container && $self->get_container eq 'ECS' ) {
     $creds = $self->get_creds_from_container;
-  }
+  } ## end if ( $self->get_container...)
   elsif ( $self->get_role ) {
     $creds = $self->get_creds_from_role;
-  }
+  } ## end elsif ( $self->get_role )
 
   croak 'unable to refresh token!'
     if !ref $creds || !keys %{$creds};
@@ -820,7 +852,7 @@ sub credential_keys {
   if ( !defined $credential_keys{AWS_SESSION_TOKEN} ) {
     delete $credential_keys{AWS_SESSION_TOKEN};
     delete $credential_keys{AWS_SESSION_TOKEN_EXPIRATION};
-  }
+  } ## end if ( !defined $credential_keys...)
 
   return \%credential_keys;
 } ## end sub credential_keys
@@ -857,14 +889,14 @@ sub get_aws_access_key_id {
 
   if ( !$self->get__access_key_id ) {
     $self->set_credentials;
-  }
+  } ## end if ( !$self->get__access_key_id)
 
   my $access_key_id
     = $self->decrypt( $self->get__access_key_id, $self->_fetch_passkey );
 
   if ( !$self->get_cache ) {
     $self->set__access_key_id(undef);
-  }
+  } ## end if ( !$self->get_cache)
 
   return $access_key_id;
 } ## end sub get_aws_access_key_id
@@ -876,14 +908,14 @@ sub get_aws_secret_access_key {
 
   if ( !$self->get__secret_access_key ) {
     $self->set_credentials;
-  }
+  } ## end if ( !$self->get__secret_access_key)
 
   my $secret_access_key
     = $self->decrypt( $self->get__secret_access_key, $self->_fetch_passkey );
 
   if ( !$self->get_cache ) {
     $self->set__secret_access_key(undef);
-  }
+  } ## end if ( !$self->get_cache)
 
   return $secret_access_key;
 } ## end sub get_aws_secret_access_key
@@ -895,14 +927,14 @@ sub get_token {
 
   if ( !$self->get__session_token && $self->get_session_token_required ) {
     $self->set_credentials;
-  }
+  } ## end if ( !$self->get__session_token...)
 
   my $token
     = $self->decrypt( $self->get__session_token, $self->_fetch_passkey );
 
   if ( !$self->get_cache ) {
     $self->set__session_token(undef);
-  }
+  } ## end if ( !$self->get_cache)
 
   return $token;
 } ## end sub get_token
@@ -916,7 +948,7 @@ sub set_aws_access_key_id {
 
   if ($aws_access_key_id) {
     $key = $self->encrypt( $aws_access_key_id, $passkey );
-  }
+  } ## end if ($aws_access_key_id)
 
   return $self->set__access_key_id($key);
 } ## end sub set_aws_access_key_id
@@ -930,7 +962,7 @@ sub set_aws_secret_access_key {
 
   if ($aws_secret_access_key) {
     $key = $self->encrypt( $aws_secret_access_key, $passkey );
-  }
+  } ## end if ($aws_secret_access_key)
 
   return $self->set__secret_access_key($key);
 
@@ -945,7 +977,7 @@ sub set_token {
 
   if ($session_token) {
     $token = $self->encrypt( $session_token, $passkey );
-  }
+  } ## end if ($session_token)
 
   return $self->set__session_token($token);
 } ## end sub set_token
@@ -961,10 +993,10 @@ sub decrypt {
 
   if ( ref $self->get_decrypt && reftype( $self->get_decrypt ) eq 'CODE' ) {
     return $self->get_decrypt->( $str, $passkey || $self->_fetch_passkey );
-  }
+  } ## end if ( ref $self->get_decrypt...)
   else {
     return $self->_crypt( $str, 'decrypt', $passkey );
-  }
+  } ## end else [ if ( ref $self->get_decrypt...)]
 } ## end sub decrypt
 
 ########################################################################
@@ -974,10 +1006,10 @@ sub encrypt {
 
   if ( ref $self->get_encrypt && reftype( $self->get_encrypt ) eq 'CODE' ) {
     return $self->get_encrypt->( $str, $passkey || $self->_fetch_passkey );
-  }
+  } ## end if ( ref $self->get_encrypt...)
   else {
     return $self->_crypt( $str, 'encrypt', $passkey );
-  }
+  } ## end else [ if ( ref $self->get_encrypt...)]
 
 } ## end sub encrypt
 
@@ -985,7 +1017,7 @@ sub encrypt {
 sub create_passkey {
 ########################################################################
   return sprintf PASSKEY_FORMAT, rand RANDOM_VALUE, rand RANDOM_VALUE;
-}
+} ## end sub create_passkey
 
 ########################################################################
 sub rotate_passkey {
@@ -1006,13 +1038,13 @@ sub rotate_passkey {
     # if caller has his own passkey generator, don't reset
     if ( !ref $self->get_passkey ) {
       $self->set_passkey($new_passkey);
-    }
+    } ## end if ( !ref $self->get_passkey)
   } ## end if ( $new_passkey && !...)
   else {
     $new_passkey = $self->create_passkey;
 
     $self->rotate_credentials($new_passkey);
-  }
+  } ## end else [ if ( $new_passkey && !...)]
 
   return $new_passkey;
 } ## end sub rotate_passkey
@@ -1021,7 +1053,7 @@ sub rotate_passkey {
 sub rotate_credentials {
 ########################################################################
   goto &rotate_passkey;
-}
+} ## end sub rotate_credentials
 
 # +-----------------+
 # | PRIVATE METHODS |
@@ -1034,7 +1066,7 @@ sub _init_logger {
 
   if ( !$self->get_logger || !ref $self->get_logger ) {
     $self->set_default_logger;
-  }
+  } ## end if ( !$self->get_logger...)
 
   $self->get_logger->debug( 'using ' . ref( $self->get_logger ) . ' logger' );
 
@@ -1061,23 +1093,23 @@ sub _set_defaults {
 
   if ( !$self->get_order ) {
     $self->set_order($default_search_order);
-  }
+  } ## end if ( !$self->get_order)
 
   if ( !ref $self->get_order ) {
     $self->set_order( [ split /\s*,\s*/xsm, $self->get_order ] );
-  }
+  } ## end if ( !ref $self->get_order)
   elsif ( ref $self->get_order && reftype( $self->get_order ) ne 'ARRAY' ) {
     croak 'order must be a comma delimited string or array ref';
-  }
+  } ## end elsif ( ref $self->get_order...)
 
   foreach my $loc ( @{ $self->get_order } ) {
     croak "invalid credential location in search order:  [$loc]"
       if !any {/^$loc$/xsm} @{$default_search_order};
-  }
+  } ## end foreach my $loc ( @{ $self->...})
 
   if ( !$self->get_profile && any {/file/xsm} @{ $self->get_order } ) {
     $self->set_profile( $ENV{'AWS_PROFILE'} );
-  }
+  } ## end if ( !$self->get_profile...)
 
   $self->set_raise_error( $self->get_raise_error // TRUE );
   $self->set_print_error( $self->get_print_error // TRUE );
@@ -1093,10 +1125,10 @@ sub _fetch_passkey {
   my $passkey = eval {
     if ( ref $self->get_passkey && reftype( $self->get_passkey ) eq 'CODE' ) {
       return $self->get_passkey->();
-    }
+    } ## end if ( ref $self->get_passkey...)
     else {
       return $self->get_passkey;
-    }
+    } ## end else [ if ( ref $self->get_passkey...)]
   };
 
   return $passkey;
@@ -1126,21 +1158,21 @@ sub _init_encryption {
     if ( !defined $self->get_encryption ) {
       # let's make the default to encrypt (if we can)
       $self->set_encryption( $has_crypt_cbc ? TRUE : FALSE );
-    }
+    } ## end if ( !defined $self->get_encryption)
     else {
       # don't allow encryption if Crypt::CBC not present
       $self->set_encryption( $self->get_encryption && $has_crypt_cbc );
-    }
+    } ## end else [ if ( !defined $self->get_encryption)]
 
     if ( $self->get_encryption && !$self->get_cipher ) {
       $self->set_cipher(DEFAULT_CIPHER);
-    }
+    } ## end if ( $self->get_encryption...)
 
   } ## end else [ if ( $self->get_encrypt...)]
 
   if ( $self->get_encryption && !$self->get_passkey ) {
     $self->set_passkey( $self->create_passkey );
-  }
+  } ## end if ( $self->get_encryption...)
 
   return $self->get_encryption;
 } ## end sub _init_encryption
@@ -1169,11 +1201,11 @@ sub _crypt {
   if ( $op eq 'decrypt' ) {
     $str = decode_base64($str);
     $str = ref $cipher ? $cipher->decrypt($str) : $str;
-  }
+  } ## end if ( $op eq 'decrypt' )
   else {
     $str = ref $cipher ? $cipher->encrypt($str) : $str;
     $str = encode_base64($str);
-  }
+  } ## end else [ if ( $op eq 'decrypt' )]
 
   return $str;
 } ## end sub _crypt
@@ -1229,7 +1261,7 @@ meta-data>. See L</new>.
 
 =head1 VERSION
 
-This document reverse to verion @PACKAGE_VERION@ of
+This document reverse to verion 1.1.9 of
 C<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
